from docx import Document
from docx.shared import Cm
from linguadoc.lib import read_json
from datetime import datetime
import os

class LinguaDoc:
  """It is used for docx generation of sentence structure and KG
  """

  def __init__(self, jsonfile, lang):
    """Initialize docx template, source data
    Args:
      jsonfile (str): json file, whose content is written into doc 
      lang (str): language of the jsonfile
    """

    self.lang = lang
    _template_dir = os.path.dirname(__file__)
    self.template = os.path.join(_template_dir, lang+'_template.docx')
    self.back_cover = os.path.join(_template_dir, 'back_cover.png')
    self.jsonfile = jsonfile
    self.data = read_json(self.jsonfile)

  def gen_doc(self, title, output="result.docx"):
    """Generate docx file
    Args:
      title (str): title written in ppt home slide
      output (str): output docx file name 
    """
    document = Document(self.template)
    document._body.clear_content()
    document.add_paragraph(title, style="Title")
    document.add_paragraph(title, style='Subtitle')
    created_time = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
    document.add_paragraph('歧舌-'+created_time, style='Quote')

    for s in self.data:
      sentence = s["sentence"]
      document.add_heading("{}\n{}".format(sentence["text"], sentence["meaning"]), level=1)

      document.add_heading("句型结构", level=2)

      document.add_heading(s["structure_rep"], level=3)
      structure = s["structure"]
      for ele in structure:
        if ele["explanation"]:
          p = document.add_paragraph("{}    {}".format(ele["text"], ele["meaning"]), style='List Bullet')

      document.add_heading("知识要点", level=2)

      kg = s["kg"]
      for key, value in kg.items():
        for v in value: 
          p = document.add_paragraph("{}    {}".format(key, v["text"]), style='List Bullet')

    document.add_picture(self.back_cover, width=Cm(15.24))

    document.save(output)




from linguadoc import LinguaDoc
import click
import hashlib
import os
import json

@click.command()
@click.option("--sourcejson", prompt="source json file path", help="Specify the source json file path")
@click.option("--lang", prompt="language", help="Specify the language")
@click.option("--destdocx", prompt="destination docx file path", help="Specify the docx file path")
@click.option("--title", default="test", help="Specify doc title")
def gen_lingua_docx(sourcejson, lang, destdocx, title):
  phase = {"step": 1, "msg": "Start doc generation"}
  print(json.dumps(phase))

  doc = LinguaDoc(sourcejson, lang)
  doc.gen_doc(title, destdocx)

  phase = {"step": 2, "msg": "Finish doc generation"}
  print(json.dumps(phase))




import json

def read_json(jsonfile):
  data = []
  with open(jsonfile) as f:
    data = json.load(f)
  return data

def write_json(content, filename):
  with open(filename, 'w') as outfile:
    json.dump(content, outfile) 

def add_bracket(ex):
  return " (" + ex + ")" if ex!=None else "" 




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['linguadoc']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0.3,<9.0.0', 'python-docx>=0.8.11,<0.9.0']

entry_points = \
{'console_scripts': ['gen_lingua_docx = linguadoc._entry:gen_lingua_docx']}

setup_kwargs = {
    'name': 'linguadoc',
    'version': '0.1.1',
    'description': 'DOC generator for language learning',
    'long_description': '# Installation\n\n```\npip3 install --verbose linguadoc \n```\n\n# Usage\n\nPlease refer to [api docs](https://qishe-nlp.github.io/linguadoc/).\n\n### Execute usage\n\n* Convert json into docx\n```\ngen_lingua_docx --sourcejson [source.json] --lang [en/de/es] --destdocx [output.docx] --title [test_title]\n```\n\n### Package usage\n```\n\n```\n\n# Development\n\n### Clone project\n```\ngit clone https://github.com/qishe-nlp/linguadoc.git\n```\n\n### Install [poetry](https://python-poetry.org/docs/)\n\n### Install dependencies\n```\npoetry update\n```\n\n### Test\n```\npoetry run pytest -rP --capture=sys\n```\nwhich run tests under `tests/*`\n\n\n### Execute\n```\npoetry run gen_lingua_docx --help\n```\n\n### Create sphinx docs\n```\npoetry shell\ncd apidocs\nsphinx-apidoc -f -o source ../linguadoc\nmake html\npython -m http.server -d build/html\n```\n\n### Host docs on github pages\n```\ncp -rf apidocs/build/html/* docs/\n```\n\n### Build\n* Change `version` in `pyproject.toml` and `linguadoc/__init__.py`\n* Build python package by `poetry build`\n\n### Git commit and push\n\n### Publish from local dev env\n* Set pypi test environment variables in poetry, refer to [poetry doc](https://python-poetry.org/docs/repositories/)\n* Publish to pypi test by `poetry publish -r test`\n\n### Publish through CI \n* Github action build and publish package to [test pypi repo](https://test.pypi.org/)\n\n```\ngit tag [x.x.x]\ngit push origin master\n```\n\n* Manually publish to [pypi repo](https://pypi.org/) through [github action](https://github.com/qishe-nlp/linguappt/actions/workflows/pypi.yml)\n\n',
    'author': 'Phoenix Grey',
    'author_email': 'phoenix.grey0108@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/qishe-nlp/linguadoc',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
